var searchData=
[
  ['terminology_0',['Terminology',['../keymap-text-format-v1-v2.html#terminology',1,'']]],
  ['test_20my_20custom_20layout_20without_20installing_20it_1',['How do I test my custom layout without installing it?',['../faq.html#how-do-i-test-my-custom-layout-without-installing-it',1,'']]],
  ['testing_20a_20custom_20configuration_2',['Testing a custom configuration',['../debugging.html#testing-custom-config',1,'']]],
  ['text_20format_3',['text format',['../keymap-text-format-v1-v2.html#introduction-to-the-xkb-text-format',1,'Introduction to the XKB text format'],['../xkbcommon-compatibility.html#keymap-text-format',1,'Keymap text format'],['../todo.html#_todo000004',1,'Keymap text format'],['../release-notes.html#keymap-text-format-1',1,'Keymap text format'],['../release-notes.html#rules-text-format',1,'Rules text format'],['../xkb-intro.html#xkb-the-text-format',1,'XKB the text format'],['../todo.html#_todo000001',1,'XKB the text format'],['../error-index.html#XKB-742',1,'XKB-742 – Incompatible keymap text format']]],
  ['text_20format_20v1_20and_20v2_4',['The XKB keymap text format, V1 and V2',['../keymap-text-format-v1-v2.html',1,'']]],
  ['that_20trigger_20modifiers_5',['How to get the keys that trigger modifiers?',['../faq.html#how-to-get-the-keys-that-trigger-modifiers',1,'']]],
  ['the_20“xkb_5fcompat”_20section_6',['The “xkb_compat” section',['../keymap-text-format-v1-v2.html#the-xkb_compat-section',1,'']]],
  ['the_20“xkb_5fgeometry”_20section_7',['The “xkb_geometry” section',['../keymap-text-format-v1-v2.html#the-xkb_geometry-section',1,'']]],
  ['the_20“xkb_5fkeycodes”_20section_8',['The “xkb_keycodes” section',['../keymap-text-format-v1-v2.html#the-xkb_keycodes-section',1,'']]],
  ['the_20“xkb_5fkeymap”_20block_9',['The “xkb_keymap” block',['../keymap-text-format-v1-v2.html#the-xkb_keymap-block',1,'']]],
  ['the_20“xkb_5fsymbols”_20section_10',['The “xkb_symbols” section',['../keymap-text-format-v1-v2.html#the-xkb_symbols-section',1,'']]],
  ['the_20“xkb_5ftypes”_20section_11',['The “xkb_types” section',['../keymap-text-format-v1-v2.html#the-xkb_types-section',1,'']]],
  ['the_20file_12',['Format of the file',['../rule-file-format.html#format-of-the-file',1,'']]],
  ['the_20include_20mechanism_13',['The include mechanism',['../keymap-text-format-v1-v2.html#xkb-include',1,'']]],
  ['the_20keyboard_20keymap_20configuration_14',['XKB the keyboard keymap configuration',['../xkb-intro.html#xkb-the-config',1,'']]],
  ['the_20keyboard_20layouts_20defined_15',['Where are the keyboard layouts defined?',['../faq.html#where-are-the-keyboard-layouts-defined',1,'']]],
  ['the_20keys_20that_20trigger_20modifiers_16',['How to get the keys that trigger modifiers?',['../faq.html#how-to-get-the-keys-that-trigger-modifiers',1,'']]],
  ['the_20protocol_17',['XKB the protocol',['../xkb-intro.html#xkb-the-protocol',1,'']]],
  ['the_20real_20modifier_20map_18',['Setting the real modifier map',['../keymap-text-format-v1-v2.html#set-real-mod-map',1,'']]],
  ['the_20rules_20file_19',['The rules file',['../rule-file-format.html',1,'']]],
  ['the_20system_20sections_20',['Overriding the system sections',['../user-configuration.html#overriding-the-system-sections',1,'']]],
  ['the_20text_20format_21',['the text format',['../xkb-intro.html#xkb-the-text-format',1,'XKB the text format'],['../todo.html#_todo000001',1,'XKB the text format']]],
  ['the_20virtual_20modifier_20encoding_22',['How to get the virtual modifier encoding?',['../faq.html#how-to-get-the-virtual-modifier-encoding',1,'']]],
  ['the_20virtual_20modifier_20map_23',['Setting the virtual modifier map',['../keymap-text-format-v1-v2.html#set-virtual-mod-map',1,'']]],
  ['the_20xkb_20keymap_20text_20format_20v1_20and_20v2_24',['The XKB keymap text format, V1 and V2',['../keymap-text-format-v1-v2.html',1,'']]],
  ['the_20xkb_20text_20format_25',['Introduction to the XKB text format',['../keymap-text-format-v1-v2.html#introduction-to-the-xkb-text-format',1,'']]],
  ['to_20get_20the_20keys_20that_20trigger_20modifiers_26',['How to get the keys that trigger modifiers?',['../faq.html#how-to-get-the-keys-that-trigger-modifiers',1,'']]],
  ['to_20get_20the_20virtual_20modifier_20encoding_27',['How to get the virtual modifier encoding?',['../faq.html#how-to-get-the-virtual-modifier-encoding',1,'']]],
  ['to_20switch_20between_20layouts_20not_20work_28',['Why does my key combination to switch between layouts not work?',['../faq.html#why-does-my-key-combination-to-switch-between-layouts-not-work',1,'']]],
  ['to_20the_20xkb_20text_20format_29',['Introduction to the XKB text format',['../keymap-text-format-v1-v2.html#introduction-to-the-xkb-text-format',1,'']]],
  ['to_20x11_30',['Relation to X11',['../index.html#relation-to-x11',1,'']]],
  ['to_20xkb_31',['Introduction to XKB',['../xkb-intro.html',1,'']]],
  ['todo_20list_32',['Todo List',['../todo.html',1,'']]],
  ['tools_33',['Tools',['../index.html#tools',1,'Tools'],['../release-notes.html#tools-1',1,'Tools'],['../release-notes.html#tools-2',1,'Tools'],['../release-notes.html#tools-3',1,'Tools'],['../release-notes.html#tools-4',1,'Tools'],['../release-notes.html#tools-5',1,'Tools'],['../release-notes.html#tools-6',1,'Tools'],['../release-notes.html#tools-7',1,'Tools'],['../release-notes.html#tools-8',1,'Tools'],['../release-notes.html#tools-9',1,'Tools'],['../release-notes.html#tools-10',1,'Tools']]],
  ['tools_34',['tools',['../debugging.html#advanced-tools',1,'Advanced tools'],['../debugging.html#available-tools',1,'Available tools'],['../debugging.html#basic-tools',1,'Basic tools']]],
  ['tools_20replacement_35',['Legacy X tools replacement',['../faq.html#legacy-x-tools-replacement',1,'']]],
  ['transformations_36',['Keysym Transformations',['../group__keysyms.html',1,'']]],
  ['trigger_20modifiers_37',['How to get the keys that trigger modifiers?',['../faq.html#how-to-get-the-keys-that-trigger-modifiers',1,'']]],
  ['triggering_20another_20latch_20or_20lock_38',['How do I break a latch before triggering another latch or lock?',['../faq.html#how-do-i-break-a-latch-before-triggering-another-latch-or-lock',1,'']]],
  ['two_20levels_39',['Two levels',['../keymap-text-format-v1-v2.html#two-levels',1,'']]],
  ['type_40',['Type',['../keymap-text-format-v1-v2.html#key-type-setting',1,'']]],
  ['type_41',['type',['../error-index.html#XKB-150',1,'XKB-150 – Wrong statement type'],['../error-index.html#XKB-183',1,'XKB-183 – Cannot infer key type'],['../error-index.html#XKB-286',1,'XKB-286 – Undefined key type'],['../error-index.html#XKB-578',1,'XKB-578 – Wrong field type'],['../error-index.html#XKB-784',1,'XKB-784 – Invalid expression type'],['../error-index.html#XKB-844',1,'XKB-844 – Unknown action type'],['../error-index.html#XKB-971',1,'XKB-971 – Undeclared modifiers in key type']]],
  ['type_20definitions_42',['Type definitions',['../keymap-text-format-v1-v2.html#key-type-statement',1,'']]],
  ['type_20definitions_43',['XKB-407 – Conflicting key type definitions',['../error-index.html#XKB-407',1,'']]],
  ['type_20level_20names_44',['XKB-239 – Conflicting key type level names',['../error-index.html#XKB-239',1,'']]],
  ['type_20map_20entry_45',['XKB-266 – Conflicting key type map entry',['../error-index.html#XKB-266',1,'']]],
  ['type_20merging_20groups_46',['XKB-893 – Conflicting key type merging groups',['../error-index.html#XKB-893',1,'']]],
  ['type_20preserve_20entries_47',['XKB-043 – Conflicting key type preserve entries',['../error-index.html#XKB-043',1,'']]],
  ['type_20preserve_20result_48',['XKB-195 – Illegal key type preserve result',['../error-index.html#XKB-195',1,'']]],
  ['types_20examples_49',['Key types examples',['../keymap-text-format-v1-v2.html#key-type-examples',1,'']]],
  ['types_20work_50',['How key types work',['../keymap-text-format-v1-v2.html#how-key-types-work',1,'']]]
];
